Struct FmtBuffer
Source pub struct FmtBuffer<const N: usize> {
buf: [u8; N],
pos: usize,
}
Stack-allocated, fixed-size [core::fmt::Write] buffer for no-alloc contexts
(interrupt handlers, panic path). Writes beyond capacity N are silently dropped.
Create an empty buffer with all bytes zeroed.
Return the bytes written so far as a &str (empty on invalid UTF-8).
Writes a string slice into this writer, returning whether the write
succeeded.
Read more
Writes a [
char] into this writer, returning whether the write succeeded.
Read more
Glue for usage of the [
write!] macro with implementors of this trait.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.